WireframeIconTokens class
- Inheritance
-
- Object
- OudsIconTokens
- WireframeIconTokens
Constructors
- WireframeIconTokens(OudsProvidersTokens providersTokens)
Properties
- colorContentStatusWarningExternalShape ↔ Color
-
getter/setter pairinherited-setteroverride-getter
- colorContentStatusWarningInternalShape ↔ Color
-
getter/setter pairinherited-setteroverride-getter
- colorContentStatusWarningInverseExternalShape ↔ Color
-
getter/setter pairinherited-setteroverride-getter
- colorContentStatusWarningInverseInternalShape ↔ Color
-
getter/setter pairinherited-setteroverride-getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- providersTokens → OudsProvidersTokens
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited